powered by
Default control parameters for Generalized co-sparse factor regresion
gofar_control( maxit = 5000, epsilon = 1e-06, elnetAlpha = 0.95, gamma0 = 1, se1 = 1, spU = 0.5, spV = 0.5, lamMaxFac = 1, lamMinFac = 1e-06, initmaxit = 2000, initepsilon = 1e-06, equalphi = 1, objI = 1, alp = 60 )
maximum iteration for each sequential steps
tolerence value set for convergene of gcure
elastic net penalty parameter
power parameter in the adaptive weights
apply 1se sule for the model;
maximum proportion of nonzero elements in each column of U
maximum proportion of nonzero elements in each column of V
a multiplier of calculated lambda_max
a multiplier of determing lambda_min as a fraction of lambda_max
maximum iteration for initialization problem
tolerence value for convergene in the initialization problem
dispersion parameter for all gaussian outcome equal or not 0/1
1 or 0 convergence on the basis of objective function or not
scaling factor corresponding to poisson outcomes
a list of controling parameter.
Mishra, Aditya, Dipak K. Dey, Yong Chen, and Kun Chen. Generalized co-sparse factor regression. Computational Statistics & Data Analysis 157 (2021): 107127
# NOT RUN { # control variable for GOFAR(S) and GOFAR(P) control <- gofar_control() # }
Run the code above in your browser using DataLab